using System.Reflection;

namespace Cogwheel;

/// <summary>
/// Represents a command in the Cogwheel system.
/// </summary>
public class Command : ICommand
{
    /// <summary>
    /// Gets the name of the command.
    /// </summary>
    public string Name { get; }

    /// <summary>
    /// Gets the description of the command.
    /// </summary>
    public string Description { get; }

    /// <summary>
    /// Gets the method associated with the command.
    /// </summary>
    public MethodBase Method { get; }

    /// <summary>
    /// Initializes a new instance of the <see cref="Command"/> class.
    /// </summary>
    /// <param name="name">The name of the command.</param>
    /// <param name="description">The description of the command.</param>
    /// <param name="method">The method associated with the command.</param>
    public Command(string name, string description, MethodBase method)
    {
        Name = name;
        Description = description;
        Method = method;
    }
}