namespace Cogwheel;

/// <summary>
/// Interface for the Cogwheel console.
/// </summary>
public interface ICogwheelConsole
{
    /// <summary>
    /// Gets or sets the opening message of the console.
    /// </summary>
    public string OpeningMessage { get; set; }

    /// <summary>
    /// Gets or sets a value indicating whether the console is running.
    /// </summary>
    public bool IsRunning { get; set; }

    /// <summary>
    /// Gets or sets the commands manager associated with the console.
    /// </summary>
    public CommandsManager CommandsManager { get; set; }

    /// <summary>
    /// Initializes the console with the specified commands manager.
    /// </summary>
    /// <param name="commandsManager">The commands manager to use.</param>
    public void Initialize(CommandsManager commandsManager);

    /// <summary>
    /// Logs a message to the console (Will cause a new line).
    /// </summary>
    /// <param name="message">The message to log.</param>
    public void Log(string message);

    /// <summary>
    /// Logs an error message to the console.
    /// </summary>
    /// <param name="message">The error message to log.</param>
    public void LogError(string message);

    /// <summary>
    /// Logs a warning message to the console.
    /// </summary>
    /// <param name="message">The warning message to log.</param>
    public void LogWarning(string message);

    /// <summary>
    /// Writes a message to the console (Will not cause a new line).
    /// </summary>
    /// <param name="message">The message to write.</param>
    public void Write(string message);

    /// <summary>
    /// Clears the console.
    /// </summary>
    public void ClearConsole();

    /// <summary>
    /// Exits the console.
    /// </summary>
    public void Exit();
}